@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from rest_framework_extensions.cache.mixins import CacheResponseMixin
+from rest_framework_extensions.etag.mixins import ReadOnlyETAGMixin, ETAGMixin
 
 
 class DetailSerializerMixin(object):
@@ -25,4 +27,12 @@ class DetailSerializerMixin(object):
         if self.queryset_detail is not None and is_for_detail:
             return self.queryset_detail._clone()  # todo: test _clone()
         else:
-            return super(DetailSerializerMixin, self).get_queryset()
\ No newline at end of file
+            return super(DetailSerializerMixin, self).get_queryset()
+
+
+class ReadOnlyCacheResponseAndETAGMixin(ReadOnlyETAGMixin, CacheResponseMixin):
+    pass
+
+
+class CacheResponseAndETAGMixin(ETAGMixin, CacheResponseMixin):
+    pass
\ No newline at end of file
